#
# Copyright 2015, SUSE Linux GmbH
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

module Crowbar
  module Client
    module Util
      class ApiVersion
        attr_accessor :version

        def initialize(version)
          @version = version
        end

        def headers
          if version == 1.0
            {
              "Accept" => "application/json",
              "Content-Type" => "application/json"
            }
          else
            {
              "Accept" => "application/vnd.crowbar.v#{version}+json",
              "Content-Type" => "application/json"
            }
          end
        end

        class << self
          def default
            os_release_file = "/etc/os-release"

            if File.exist?(os_release_file)
              os_release = Hash[
                File.open(os_release_file).read.scan(/(\S+)\s*=\s*"([^"]+)/)
              ]

              return 1.0 if os_release["VERSION_ID"] == "12.1" && os_release["ID"] == "sles"
            end

            2.0
          end
        end
      end
    end
  end
end
